namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::name_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::localized_name_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_localized_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::description_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_description_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Action::description_set( ::efl::eolian::in_traits<int>::type id,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_action_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<  ::efl::eina::range_list<Elm_Atspi_Action>>::type Atspi_Action::actions_get() const
{
   Eina_List * __return_value =  ::elm_interface_atspi_action_actions_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list<Elm_Atspi_Action>>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Action::action_do( ::efl::eolian::in_traits<int>::type id) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_action_do(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
} } 
namespace eo_cxx {
namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::name_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::localized_name_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_localized_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Action::description_get( ::efl::eolian::in_traits<int>::type id) const
{
   const char * __return_value =  ::elm_interface_atspi_action_description_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Action::description_set( ::efl::eolian::in_traits<int>::type id,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_action_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<  ::efl::eina::range_list<Elm_Atspi_Action>>::type Atspi_Action::actions_get() const
{
   Eina_List * __return_value =  ::elm_interface_atspi_action_actions_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list<Elm_Atspi_Action>>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACTION_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<bool>::type Atspi_Action::action_do( ::efl::eolian::in_traits<int>::type id) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_action_do(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(id));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
#endif
inline elm::interface::Atspi_Action::operator ::elm::interface::Atspi_Action() const { return *static_cast< ::elm::interface::Atspi_Action const*>(static_cast<void const*>(this)); }
inline elm::interface::Atspi_Action::operator ::elm::interface::Atspi_Action&() { return *static_cast< ::elm::interface::Atspi_Action*>(static_cast<void*>(this)); }
inline elm::interface::Atspi_Action::operator ::elm::interface::Atspi_Action const&() const { return *static_cast< ::elm::interface::Atspi_Action const*>(static_cast<void const*>(this)); }
} } }

